@@ -241,6 +241,7 @@ fill_monitor (int prop_changed, struct bgState *state)
 	    GdkColor color;
 	    GdkFont  *font;
 	    gint     height, width;
+            const char *disabled_string = _("Disabled");
 
 	    screen = GTK_PIXMAP (GTK_BIN (monitor)->child)->pixmap;
 	    cw = MONITOR_CONTENTS_WIDTH;
@@ -257,15 +258,15 @@ fill_monitor (int prop_changed, struct bgState *state)
 	    gdk_draw_rectangle (screen, gc, TRUE, cx, cy, cw, ch);
 
 	    font = GTK_BIN(monitor)->child->style->font;
-	    width = gdk_string_width ( font, "Disabled");
-	    height = gdk_string_height ( font, "Disabled");
+	    width = gdk_string_width ( font, disabled_string);
+	    height = gdk_string_height ( font, disabled_string);
 
 	    gdk_color_white(gtk_widget_get_colormap(GTK_BIN(monitor)->child),
 			    &color);
 	    gdk_gc_set_foreground(gc, &color);
 	    gdk_draw_string (screen, font, gc, 
 			     cx + (cw-width)/2, cy + (ch-height)/2 + height/2,
-			     "Disabled");
+			     disabled_string);
 
 	    gdk_gc_unref (gc);
 	    gtk_widget_queue_draw (monitor);
@@ -640,7 +641,7 @@ color_setup (struct bgState *state)
 		       GTK_SIGNAL_FUNC(color_sel_set), NULL);
     gtk_table_attach_defaults (GTK_TABLE(table), gtk_label_new (_("Color 1")), 0, 1, 0, 1);
     gtk_table_attach (GTK_TABLE(table), cp1, 0, 1, 1, 2, 0, 0, 0, 0);
-    gtk_table_attach_defaults (GTK_TABLE(table), cp1, 0, 1, 1, 2);
+/*    gtk_table_attach_defaults (GTK_TABLE(table), cp1, 0, 1, 1, 2);*/
 /*    gtk_table_attach_defaults (GTK_TABLE(table), gtk_hseparator_new (), 0, 1, 2, 3);*/
     cl2 = gtk_label_new (_("Color 2"));
     gtk_table_attach_defaults (GTK_TABLE(table), cl2, 0, 1, 3, 4);
@@ -1098,6 +1099,7 @@ background_apply (struct bgState *state)
 	break;
       default:
 	choice = tiledButton;
+	break;
     }
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (choice), TRUE);
 
@@ -1294,6 +1296,7 @@ img_dnd_drop (GtkWidget *widget, GdkDragContext *context, gint x, gint y,
 		}
 		break;
 	default:
+		break;
 	}
 }
 
@@ -1560,6 +1563,7 @@ parse_func (int key, char *arg, struct argp_state *state)
 
 	default:
 		return ARGP_ERR_UNKNOWN;
+		break;
 	}
 }
 
