@@ -236,9 +236,9 @@ main (int argc, char **argv)
 	init_results = gnome_capplet_init("bell-properties", VERSION,
 					  argc, argv, NULL, 0, NULL);
 	if (init_results < 0) {
-                g_warning ("an initialization error occurred while "
+                g_warning (_("an initialization error occurred while "
 			   "starting 'bell-properties-capplet'.\n"
-                           "aborting...\n");
+                           "aborting...\n"));
                 exit (1);
 	}
 
