@@ -11,7 +11,7 @@
 #include "gnome.h"
 
 typedef struct _EditorDescription EditorDescription;
-
+static gboolean ignore_changes = TRUE;
 struct _EditorDescription
 {
         gchar *name;
@@ -100,23 +100,57 @@ edit_read(void)
 {
 	gchar *original_name
                 = gnome_config_get_string("/editor/Editor/EDITOR=emacs");
+        gboolean was_set;
+        gchar    *key;
+        gint     i;
+
         original_info.executable_name = original_name;
         set_combo( original_name );
         if(original_info.name)
                 g_free(original_info.name);
+
         original_info.name = g_strdup(gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(combo)->entry)));
-        original_info.needs_term
-                = gnome_config_get_bool("/editor/Editor/NEEDS_TERM=TRUE");
-        original_info.execution_type
-                = gnome_config_get_string("/editor/Editor/EDITOR_TYPE=executable");
-        original_info.accepts_lineno
-                = gnome_config_get_bool("/editor/Editor/ACCEPTS_LINE_NO=TRUE");
+
+        for ( i=0; i < sizeof(possible_editors) / sizeof(possible_editors[0]); i++ ) {
+                if (!strcmp(possible_editors[i].name,original_info.name)) {
+                        break;
+                }
+        }
+
+        /* if no match, we pick reasonable defaults */
+        if ( i == sizeof(possible_editors) / sizeof(possible_editors[0])) {
+                original_info.needs_term = TRUE;
+                original_info.execution_type = g_strdup("executable");
+                original_info.accepts_lineno = FALSE;
+        } else {
+                original_info.needs_term = possible_editors[i].needs_term;
+                original_info.execution_type = g_strdup(possible_editors[i].execution_type);
+                original_info.accepts_lineno = possible_editors[i].accepts_lineno;
+        }
+
+        key = g_strconcat("/editor/Editor/NEEDS_TERM=", (original_info.needs_term) ?
+                          "TRUE" : "FALSE", NULL);
+        original_info.needs_term = gnome_config_get_bool_with_default(key, NULL);
+        g_free(key);
+
+        key = g_strconcat("/editor/Editor/EDITOR_TYPE=",original_info.execution_type,
+                          NULL);
+        if (original_info.execution_type)
+                g_free(original_info.execution_type);
+        original_info.execution_type = gnome_config_get_string_with_default(key, NULL);
+        g_free(key);
+
+        key = g_strconcat("/editor/Editor/ACCEPTS_LINE_NO=", 
+                          (original_info.accepts_lineno) ? "TRUE" : "FALSE", NULL);
+        original_info.accepts_lineno = gnome_config_get_bool_with_default(key, NULL);
+        g_free(key);
 }
 
 static void
 edit_changed (GtkWidget *widget, gpointer data)
 {
-        capplet_widget_state_changed(CAPPLET_WIDGET (capplet), TRUE);
+        if (!ignore_changes)
+                capplet_widget_state_changed(CAPPLET_WIDGET (capplet), TRUE);
 }
 
 static void
@@ -167,6 +201,7 @@ edit_write(void)
 static void
 edit_revert (void)
 {
+        ignore_changes = TRUE;
         gnome_config_set_string("/editor/Editor/EDITOR", original_info.name );
         gnome_config_set_bool("/editor/Editor/NEEDS_TERM", original_info.needs_term );
         gnome_config_set_string("/editor/Editor/EDITOR_TYPE", original_info.execution_type );
@@ -175,6 +210,7 @@ edit_revert (void)
 
         edit_read ();
         edit_sync (original_info);
+        ignore_changes = FALSE;
 }
 
 static void
@@ -186,7 +222,7 @@ edit_setup(void)
         gint i;
 
         capplet = capplet_widget_new();
-
+        ignore_changes = TRUE;
 	vbox = gtk_vbox_new(FALSE, GNOME_PAD_SMALL);
 	gtk_container_set_border_width(GTK_CONTAINER(vbox), GNOME_PAD);
 
@@ -230,6 +266,7 @@ edit_setup(void)
 
         gtk_container_add (GTK_CONTAINER (capplet), vbox);
         gtk_widget_show_all (capplet);
+        ignore_changes = FALSE;
 }
 
 
@@ -245,6 +282,7 @@ main (int argc, char **argv)
         case -1:
                 return 0;
         default:
+		break;
         }
 
         edit_setup ();
