@@ -21,7 +21,6 @@ static gint keyboard_delay;
 static gint keyboard_repeat;
 static gint click_volume;
 static gint click_on_keypress;
-static gint enable_auto_repeat;
 static XKeyboardState kbdstate;
 static XKeyboardControl kbdcontrol;
 static GtkWidget *capplet;
@@ -37,17 +36,17 @@ keyboard_read(void)
 {
 	gboolean repeat_default, click_default;
 
-	keyboard_rate = gnome_config_get_int("/Desktop/Keyboard/rate=-1");
+	keyboard_rate = gnome_config_get_int("/Desktop/Keyboard/rate=-");
 	keyboard_delay = gnome_config_get_int("/Desktop/Keyboard/delay=-1");
-	keyboard_repeat = gnome_config_get_bool_with_default ("/Desktop/Keyboard/repeat=false", &repeat_default);
+	keyboard_repeat = gnome_config_get_bool_with_default ("/Desktop/Keyboard/repeat=true", &repeat_default);
         click_volume = gnome_config_get_int("/Desktop/Keyboard/clickvolume=-1");
         click_on_keypress = gnome_config_get_bool_with_default("/Desktop/Keyboard/click=false", &click_default);
 
 	XGetKeyboardControl(GDK_DISPLAY(), &kbdstate);
 
-	if (repeat_default) {
+	if (repeat_default)
 		keyboard_repeat = kbdstate.global_auto_repeat;
-	}
+
 	if (keyboard_rate == -1 || keyboard_delay == -1) {
 #ifdef HAVE_X11_EXTENSIONS_XF86MISC_H
 		XF86MiscGetKbdSettings(GDK_DISPLAY(), &kbdsettings);
@@ -60,12 +59,11 @@ keyboard_read(void)
 #endif
 	}
 
-	if (click_default) {
+	if (click_default)
 		click_on_keypress =  (kbdstate.key_click_percent == 0);
-	}
-	if (click_volume == -1) {
+
+	if (click_volume == -1)
 		click_volume = kbdstate.key_click_percent;
-	}
 }
 
 static void
@@ -201,7 +199,7 @@ make_scale (char *title, GtkObject *adjust, int *update_var, GtkWidget *table, i
 static void
 keyboard_setup (void)
 {
-        GtkWidget *vbox, *frame, *table, *hbox, *label, *entry;
+        GtkWidget *vbox, *frame, *table, *hbox, *label, *entry, *wtmp;
 
         vbox = gtk_vbox_new (FALSE, GNOME_PAD_SMALL);
         gtk_container_set_border_width (GTK_CONTAINER (vbox), GNOME_PAD);
@@ -256,9 +254,12 @@ keyboard_setup (void)
         vol_adjust = gtk_adjustment_new (click_volume, 0, 100, 1, 1, 0);
         vscale = make_scale (_("Click volume"), vol_adjust, &click_volume, table, 1);
 
+        wtmp = gtk_frame_new(_("Preview"));
+        gtk_widget_show(wtmp);
+        gtk_box_pack_start(GTK_BOX (vbox), wtmp, FALSE, FALSE, 0);
         hbox = gtk_hbox_new(FALSE, GNOME_PAD_SMALL);
         gtk_container_set_border_width (GTK_CONTAINER (vbox), GNOME_PAD);
-        gtk_box_pack_start(GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
+        gtk_container_add(GTK_CONTAINER(wtmp), hbox);
         gtk_widget_show(hbox);
 
         label = gtk_label_new(_("Test settings"));
@@ -303,9 +304,9 @@ main (int argc, char **argv)
 	init_results = gnome_capplet_init("keyboard-properties", VERSION,
 					  argc, argv, NULL, 0, NULL);
 	if (init_results < 0) {
-                g_warning ("an initialization error occurred while "
+                g_warning (_("an initialization error occurred while "
 			   "starting 'keyboard-properties-capplet'.\n"
-                           "aborting...\n");
+                           "aborting...\n"));
                 exit (1);
 	}
 
