@@ -130,7 +130,7 @@ initialize_main_win ()
 
 	hbox = gtk_hbox_new (FALSE, GNOME_PAD_SMALL);
 	main_win->regexp1_label = gtk_label_new ("");
-	main_win->regexp1_tag_label = gtk_label_new (_("First Regular Expresion: "));
+	main_win->regexp1_tag_label = gtk_label_new (_("First Regular Expression: "));
 	gtk_box_pack_start (GTK_BOX (vbox2), hbox, FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (hbox), main_win->regexp1_tag_label,
 			    FALSE, FALSE, 0);
@@ -138,19 +138,25 @@ initialize_main_win ()
 
 	hbox = gtk_hbox_new (FALSE, GNOME_PAD_SMALL);
 	main_win->regexp2_label = gtk_label_new ("");
-	main_win->regexp2_tag_label = gtk_label_new (_("Second Regular Expresion: "));
+	main_win->regexp2_tag_label = gtk_label_new (_("Second Regular Expression: "));
 	gtk_box_pack_start (GTK_BOX (vbox2), hbox, FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (hbox), main_win->regexp2_tag_label,
 			    FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (hbox), main_win->regexp2_label, FALSE, FALSE, 0);
 
 	/* Actions box */
-	frame = gtk_frame_new (_("Mime-Type Actions"));
+	frame = gtk_frame_new (_("Mime Type Actions"));
+	vbox2 = gtk_vbox_new (FALSE, GNOME_PAD_SMALL);
 	gtk_box_pack_start (GTK_BOX (vbox), frame, TRUE, TRUE, 0);
 	table = gtk_table_new (3, 2, FALSE);
 	gtk_table_set_row_spacings (GTK_TABLE (table), GNOME_PAD_SMALL);
 	gtk_container_set_border_width (GTK_CONTAINER (table), GNOME_PAD_SMALL);
-	gtk_container_add (GTK_CONTAINER (frame), table);
+	gtk_container_add (GTK_CONTAINER (frame), vbox2);
+	label = gtk_label_new (_("Example: emacs %f"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+	gtk_misc_set_padding (GTK_MISC (label), 2, 0);
+	gtk_box_pack_start (GTK_BOX (vbox2), label, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox2), table, FALSE, FALSE, 0);
 	label = gtk_label_new (_("Open"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_misc_set_padding (GTK_MISC (label), 2, 0);
@@ -213,8 +219,11 @@ setup_entry (gchar *key, GtkWidget *g_entry, MimeInfo *mi)
 void
 initialize_main_win_vals (void)
 {
-	MimeInfo *mi = main_win->mi;
+	MimeInfo *mi;
 	gchar *title;
+	if (main_win == NULL)
+		return;
+	mi = main_win->mi;
 	if (mi == NULL)
 		return;
 	/* now we fill in the fields with the mi stuff. */
@@ -226,7 +235,7 @@ initialize_main_win_vals (void)
 
 	gtk_widget_show_all (GNOME_DIALOG (main_win->window)->vbox);
 	/* we initialize everything */
-	title = g_strconcat ("Set actions for ", mi->mime_type, NULL);
+	title = g_strdup_printf (_("Set actions for %s"), mi->mime_type);
 	gtk_window_set_title (GTK_WINDOW (main_win->window), title);
 	g_free (title);
 	if (mi->ext[0]) {
@@ -277,11 +286,14 @@ launch_edit_window (MimeInfo *mi)
 	main_win->mi = mi;
 	initialize_main_win_vals ();
 
-	if  ((gnome_dialog_run (GNOME_DIALOG (main_win->window))) == 0) {
+	switch(gnome_dialog_run (GNOME_DIALOG (main_win->window))) {
+	case 0:
 		apply_changes (mi);
+	case 1:
+		main_win->mi = NULL;
+		gtk_widget_hide (main_win->window);
+		break;
 	}
-	main_win->mi = NULL;
-	gtk_widget_hide (main_win->window);
 }
 
 void
