@@ -1,6 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
-/* Copyright (C) 1998 Redhat Software Inc. 
+/* Copyright (C) 1998 Red Hat, Inc., Tom Tromey
  * Authors: Jonathan Blandford <jrb@redhat.com>
+ * Authors: Tom Tromey <tromey@cygnus.com>
  */
 #include <config.h>
 #include "capplet-widget.h"
@@ -111,12 +112,18 @@ static void
 mouse_apply (void)
 {
         unsigned char buttons[MAX_BUTTONS], i;
-        int num, den;
+        int num, den, max;
 
         assert (mouse_nbuttons <= MAX_BUTTONS);
 
-        for (i = 0; i < mouse_nbuttons; ++i)
-                buttons[i] = mouse_rtol ? (mouse_nbuttons - i) : (i + 1);
+
+        /* Ignore buttons above 3 -- these are assumed to be a wheel.
+           If we have a non-wheeled mouse, this may do weird things */
+        max = MAX (mouse_nbuttons, 3);
+        for (i = 0; i < max; ++i)
+                buttons[i] = mouse_rtol ? (max - i) : (i + 1);
+        for (; i < mouse_nbuttons; ++i)
+                buttons[i] = i + 1;
         XSetPointerMapping (GDK_DISPLAY (), buttons, mouse_nbuttons);
 
         if (mouse_acceleration < MAX_ACCEL)
@@ -331,9 +338,9 @@ main (int argc, char **argv)
                                           argc, argv, NULL, 0, NULL);
 
 	if (init_results < 0) {
-                g_warning ("an initialization error occurred while "
+                g_warning (_("an initialization error occurred while "
 			   "starting 'mouse-properties-capplet'.\n"
-                           "aborting...\n");
+                           "aborting...\n"));
                 exit (1);
 	}
 
