@@ -18,12 +18,13 @@
 #include <dirent.h>
 #include <errno.h>
 #include <time.h>
+#include <ctype.h>
 
 #ifndef errno
 extern int errno;
 #endif
 
-#define HAVE_REDHAT_XSCREENSAVER_RPM
+/*#define HAVE_REDHAT_XSCREENSAVER_RPM*/
 extern GtkWidget *capplet;
 extern GtkWidget *setup_button;
 extern GtkWidget *setup_label;
@@ -33,8 +34,8 @@ extern gshort waitmins;
 extern gshort dpmsmins;
 extern gboolean dpms;
 extern gboolean password;
-extern gchar *screensaver;
-extern const gchar *random_screensaver;
+extern char *screensaver;
+extern char *random_screensaver;
 extern screensaver_data *sd;
 extern GList *sdlist;
 static pid_t pid = 0;
@@ -48,7 +49,7 @@ static guint random_timer = 0;
 
 /* Loading info... */
 void
-screensaver_load ()
+screensaver_load (void)
 {
         gint defval = 0;
         ss_priority = gnome_config_get_int ("/Screensaver/Default/nice=10");
@@ -63,19 +64,19 @@ screensaver_load ()
         else if (dpmsmins < 1)
                 dpmsmins = 1;
         dpms = gnome_config_get_bool ("/Screensaver/Default/dpms=false");
-        password = gnome_config_get_bool ("/Screensaver/Default/password=true");
+        password = gnome_config_get_bool ("/Screensaver/Default/password=false");
         screensaver = gnome_config_get_string_with_default ("/Screensaver/Default/mode", &defval);
         if (defval) {
-                screensaver = random_screensaver;
+                screensaver = (char *)random_screensaver;
         } else if (!strcmp (screensaver, random_screensaver)) {
                 g_free (screensaver);
-                screensaver = random_screensaver;
+                screensaver = (char *)random_screensaver;
         }
         sd = NULL;
 }
 
 GtkWidget *
-get_and_set_min_entry ()
+get_and_set_min_entry (void)
 {
         gchar tempmin[5];
         static GtkWidget *retval = NULL;
@@ -93,7 +94,7 @@ get_and_set_min_entry ()
         return retval;
 }
 GtkWidget *
-get_and_set_pword ()
+get_and_set_pword (void)
 {
         static GtkWidget *retval = NULL;
 
@@ -108,7 +109,7 @@ get_and_set_pword ()
 }
 
 GtkAdjustment *
-get_and_set_nice ()
+get_and_set_nice (void)
 {
         static GtkAdjustment *retval = NULL;
 
@@ -123,7 +124,7 @@ get_and_set_nice ()
 }
 
 GtkWidget *
-get_and_set_dpmsmin ()
+get_and_set_dpmsmin (void)
 {
         static GtkWidget *retval = NULL;
         gchar tempmin[5];
@@ -160,18 +161,13 @@ get_and_set_dpmscheck (GtkWidget *box)
         return retval;
 }
 
-
-static gint compareItems(const void *a, const void *b)
-{
-        return strcmp((char *)a, (char *)b);
-}
 static screensaver_data *
 get_random_data ()
 {
         screensaver_data *retval;
 
         retval = g_malloc (sizeof (screensaver_data));
-        retval->name = random_screensaver;
+        retval->name = (char *)random_screensaver;
         retval->tryexec = NULL;
         retval->desktop_filename = NULL;
         retval->windowid = NULL;
@@ -185,11 +181,11 @@ get_random_data ()
         retval->setup_data = NULL;
         return retval;
 }
-void
+
+static void
 create_list (GtkCList *list, gchar *directory)
 {
         DIR *dir;
-        gchar *label;
         gchar *list_item[1];
         gint item;
         struct dirent *child;
@@ -214,7 +210,6 @@ create_list (GtkCList *list, gchar *directory)
 
         for (listp = desktop_items; listp; listp = g_list_next(listp)) {
                 gchar *name;
-                gchar *full_name;
 
                 name = listp->data;
                 prefix = g_strconcat ("=", directory, name, "=/Desktop Entry/", NULL);
@@ -297,7 +292,7 @@ create_list (GtkCList *list, gchar *directory)
 }
 
 GtkWidget *
-get_and_set_mode()
+get_and_set_mode(void)
 {
         screensaver_data *random;
         gchar *tempdir;
@@ -392,8 +387,6 @@ void
 launch_miniview (screensaver_data *sd)
 {
         gchar xid[11];
-        gchar *temp;
-        gchar **argv;
         int p[2];
 
         if (pid) {
@@ -446,28 +439,25 @@ launch_miniview (screensaver_data *sd)
                 return;
         }
         if (pid == 0) {
+		char *ctmp, *envpath;
+		char **argv;
+
                 close (p[0]);
-                snprintf (xid, 11,"0x%x", GDK_WINDOW_XWINDOW (monitor->window));
-#ifdef HAVE_REDHAT_XSCREENSAVER_RPM
-                temp = g_strconcat ("/usr/X11R6/lib/xscreensaver/", sd->demo, " ", sd->windowid, " ", xid, NULL);
-#else
-                temp = g_strconcat (sd->demo, " ", sd->windowid, " ", xid, NULL);
-#endif
-                argv = g_strsplit (temp, " ", -1);
-                g_free (temp);
-#ifdef HAVE_REDHAT_XSCREENSAVER_RPM
-                execv (argv[0], argv);
-#else
-                
-                temp = gnome_is_program_in_path (argv[0]);
-                
-                if (temp == NULL)
-                        _exit (0);
-                        
-                execvp (temp, argv);
-#endif
-                /* This call should never return, but if it does... */
-                _exit (0);
+                snprintf (xid, 11,"0x%x", (guint)GDK_WINDOW_XWINDOW (monitor->window));
+
+		envpath = getenv("PATH");
+		ctmp = g_strdup_printf("%s%s%s",
+				       envpath?envpath:"",
+				       envpath?":":"",
+				       "/usr/X11R6/lib/xscreensaver");
+		setenv("PATH", ctmp, 1);
+
+		argv = g_strsplit(g_strconcat(sd->demo, " ", sd->windowid, " ", xid, NULL), " ", -1);
+
+		execvp (argv[0], argv);
+
+		/* This call should never return, but if it does... */
+		_exit (0);
         }
         close (p[1]);
 
@@ -484,7 +474,7 @@ setup_callback (GtkWidget *widget, gpointer data)
 static void
 handle_list_change(void *data)
 {
-        gchar *label;
+        GString *label_string;
 
         if (sd == data)
                 return;
@@ -507,9 +497,12 @@ handle_list_change(void *data)
         }
         if (sd->args == NULL)
                 init_screensaver_data (sd);
-        label = g_strconcat (sd->name, _(" Settings"), NULL);
-        gtk_label_set (GTK_LABEL (setup_label),label);
-        g_free (label);
+
+        label_string = g_string_new (NULL);
+        g_string_sprintf (label_string, _("%s Settings..."), sd->name);
+        gtk_label_set (GTK_LABEL (setup_label),label_string->str);
+        g_string_free (label_string, TRUE);
+
         if ((sd->setup_data == NULL) || (sd->dialog != NULL))
                 gtk_widget_set_sensitive (setup_button, FALSE);
         else
@@ -678,7 +671,7 @@ dialog_callback (GtkWidget *dialog, gint button, screensaver_data *newsd)
                 if (pid_big == (pid_t) -1)
                         return;
                 if (pid_big == 0) {
-                        snprintf (xid, 11,"0x%x", GDK_WINDOW_XWINDOW (sswin));
+                        snprintf (xid, 11,"0x%x", (guint) GDK_WINDOW_XWINDOW (sswin));
 #ifdef HAVE_REDHAT_XSCREENSAVER_RPM                        
                         temp = g_strconcat ("/usr/X11R6/lib/xscreensaver/", newsd->args, " ", newsd->windowid, " ", xid, NULL);
 #else
@@ -706,14 +699,11 @@ destroy_callback (GtkWidget *widget, void *data)
                 kill (pid, SIGTERM);
 }
 void
-ok_callback ()
+ok_callback (void)
 {
         /* we want to commit our changes to disk. */
         GString *command;
         gchar temp[10];
-        gchar argv[3];
-        gint temp2;
-
 
         /* save the stuff... */
         gnome_config_set_int ("/Screensaver/Default/nice", ss_priority);
@@ -723,9 +713,11 @@ ok_callback ()
         gnome_config_set_bool ("/Screensaver/Default/password", password);
         if (screensaver)
                 gnome_config_set_string ("/Screensaver/Default/mode", screensaver);
-        else
+        else {
                 gnome_config_set_string ("/Screensaver/Default/mode", "NONE");
-
+                gnome_config_set_string ("/Screensaver/Default/command", "NONE");
+        }
+        
         system ("xscreensaver-command -exit");
         if (sd && waitmins) {
                 if (sd->dialog)
@@ -779,19 +771,20 @@ ok_callback ()
         gnome_config_sync ();
 }
 void
-page_hide_callback ()
+page_hide_callback (void)
 {
         if (sd->dialog)
                 gtk_widget_hide (sd->dialog);
 }
 void
-page_show_callback ()
+page_show_callback (void)
 {
         if (sd->dialog)
                 gtk_widget_show (sd->dialog);
 }
 void
-help_callback () {
+help_callback (void)
+{
 
   gchar *tmp;
 
@@ -803,7 +796,7 @@ help_callback () {
 
 }
 void
-try_callback ()
+try_callback (void)
 {
         GString *command;
         gchar temp[10];
@@ -861,7 +854,7 @@ try_callback ()
                 system ("xset -dpms");
 }
 void
-revert_callback ()
+revert_callback (void)
 {
         gchar *temp, *temp2;
 
@@ -885,7 +878,7 @@ revert_callback ()
         
         gdk_draw_rectangle (monitor->window,monitor->style->black_gc, TRUE, 0, 0, monitor->allocation.width, monitor->allocation.height);
 
-        temp = gnome_config_get_string ("/Screensaver/Default/command=xscreensaver -no-splash -timeout 20 -nice 10 -lock-mode");
+        temp = gnome_config_get_string ("/Screensaver/Default/command=xscreensaver -no-splash -timeout 20 -nice 10");
         if (!strchr(temp, '&')) {
                 /* ugh! */
                 temp2 = g_strconcat (temp, " &", NULL);
