@@ -1,13 +1,21 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
 /* Copyright (C) 1998 Redhat Software Inc. 
  * Authors: Jonathan Blandford <jrb@redhat.com>
+ *
+ * Support for i18n in the screenserver configuration file subsections.
+ * 1999-03-22, Pablo Satxaga <srtxg@chanae.alphanet.ch>  -- srtxg 
+ *
  */
 #include <string.h>
 
+#ifndef SIZEBUF
+#define SIZEBUF 512
+#endif
+
 #include "parser.h"
 #include "gnome.h"
 #include "capplet-widget.h"
-
+#include <libgnome/gnome-i18n.h>
 
 #define get_lrange(ssd) (get_range (ssd, 0)) 
 #define get_nrange(ssd) (get_range (ssd, 1)) 
@@ -18,7 +26,8 @@ typedef enum
         ENTRY,
         LRANGE,
         NRANGE,
-        CHECK
+        CHECK,
+        COLOR
 } W_TYPES;
 typedef struct _setup_data setup_data;
 struct _setup_data
@@ -43,9 +52,11 @@ static void entry_callback (GtkEditable *editable, const gchar *text, gint lengt
 static void entry_delete_callback (GtkEditable *editable, gint length, gint *position, setup_data *ssd);
 static void check_callback (GtkWidget *cbox, setup_data *ssd);
 static void range_callback (GtkAdjustment *adj, setup_data *ssd);
+static void color_callback (GnomeColorPicker *color_button, guint red, guint green, guint blue, guint alpha, setup_data *ssd);
 static void set_entry (setup_data *ssd);
 static void set_range (setup_data *ssd);
 static void set_check (setup_data *ssd);
+static void set_color (setup_data *ssd);
 
 
 static setup_data *
@@ -108,6 +119,9 @@ print_data (setup_data *dat)
         case CHECK:
                 g_print ("Type: CHECK\n");
                 break;
+        case COLOR:
+                g_print ("Type: COLOR\n");
+                break;
         }
         if (!dat->val_type)
                 g_print ("ValType: NULL\n");
@@ -164,16 +178,74 @@ validate_setup_data (setup_data *dat)
                     (dat->left_label == NULL))
                         return FALSE;
                 return TRUE;
+        case COLOR:
+                if ((dat->val_type == NULL) ||
+                    (dat->label == NULL) ||
+                    (dat->flag1 == NULL) ||
+                    (dat->name == NULL))
+                        return FALSE;
+                return TRUE;
         default:
                 return FALSE;
         }
 }
 static void
-parse_key (setup_data *arg_vals, gchar *key, gchar *value)
+parse_key (setup_data *arg_vals, gchar *key, gchar *value, int cpt_iter)
 {
-        if (strcmp (key, "Name") == 0)
-                arg_vals->name = g_strdup (value);
-        else if (strcmp (key, "Type") == 0) {
+    GList *lang = NULL;
+    char buf[BUFSIZ];
+    char sfx[BUFSIZ];
+    /* as the user can define several languages, and as parse_key()
+     * can receive the data in another order thant the user preferred
+     * languages order; a set of counters are defined to attach a
+     * notion of "priority" to the translated labels. the various
+     * cpt_* hold the priority level of the language used in a previous
+     * matching entry; i holds the currently tryed language priority;
+     * if i is lower then the previous translated string is replaced 
+     * whith the one translated to the currently tested language.
+     * cpt_iter however doesn't hold a priority but tells (if equal to 0)
+     * that a new configuration section is parsed, and then reset
+     * the others cpt_* counters.        -- srtxg
+     */
+    static int cpt_n,cpt_l,cpt_c,cpt_ll,cpt_rl;
+    int i=0;
+
+    /* we are in a new config section to parse; reset the priority
+     * counters to a value high enough so they will allways be less
+     * priority (I hope nobody has a $LANGUAGE variable whith 100+ 
+     * preferences :)    -- srtxg
+     */ 
+    if (cpt_iter==0) {
+	cpt_n=100;
+	cpt_l=100;
+	cpt_c=100;
+	cpt_ll=100;
+	cpt_rl=100;
+    }
+
+    lang = gnome_i18n_get_language_list ("LC_MESSAGE");
+    do
+    {
+	if (lang) {
+		if (strcmp("C",(gchar *) lang->data) !=0 && strcmp("POSIX",(gchar *)lang->data)!=0)
+			snprintf(sfx,SIZEBUF,"[%s]",(gchar *)lang->data);
+		else
+			sfx[0]='\0';
+		lang=lang->next;
+	} else {
+		sfx[0]='\0';
+	}
+
+#define TEST_FOR_I18N_KEY(a)	( (snprintf(buf,SIZEBUF,"%s%s",a,sfx)) && \
+				  (strcmp (key, buf) == 0) )
+
+        if TEST_FOR_I18N_KEY("Name") {
+                if (cpt_n > i) {
+			 arg_vals->name = g_strdup (value);
+			 cpt_n=i;
+		}
+		break;
+        } else if (strcmp (key, "Type") == 0) {
                 if (strcmp (value, "Entry") == 0)
                         arg_vals->widget_type = ENTRY;
                 else if (strcmp (value, "LRange") == 0)
@@ -182,20 +254,45 @@ parse_key (setup_data *arg_vals, gchar *key, gchar *value)
                         arg_vals->widget_type = NRANGE;
                 else if (strcmp (value, "Check") == 0)
                         arg_vals->widget_type = CHECK;
-        } else if (strcmp (key, "ValType") == 0)
-                arg_vals->val_type = g_strdup (value);
-        else if (strcmp (key, "Flag") == 0)
-                arg_vals->flag1 = g_strdup (value);
-        else if (strcmp (key, "Flag2") == 0)
-                arg_vals->flag2 = g_strdup (value);
-        else if (strcmp (key, "Label") == 0)
-                arg_vals->label = g_strdup (value);
-        else if (strcmp (key, "Comment") == 0)
-                arg_vals->comment = g_strdup (value);
-        else if (strcmp (key, "LeftLabel") == 0)
-                arg_vals->left_label = g_strdup (value);
-        else if (strcmp (key, "RightLabel") == 0)
-                arg_vals->right_label = g_strdup (value);
+                else if (strcmp (value, "Color") == 0)
+                        arg_vals->widget_type = COLOR;
+		break;
+        } else if (strcmp (key, "ValType") == 0) {
+                arg_vals->val_type = g_strdup (value); break;
+        } else if (strcmp (key, "Flag") == 0) {
+                arg_vals->flag1 = g_strdup (value); break;
+        } else if (strcmp (key, "Flag2") == 0) {
+                arg_vals->flag2 = g_strdup (value); break;
+        } else if TEST_FOR_I18N_KEY("Label") {
+                if (cpt_l > i) {
+			arg_vals->label = g_strdup (value);
+			cpt_l=i;
+		}
+		break;
+        } else if TEST_FOR_I18N_KEY("Comment") {
+		if (cpt_c > i) {
+                	arg_vals->comment = g_strdup (value);
+			cpt_c=i;
+		}
+		break;
+        } else if TEST_FOR_I18N_KEY("LeftLabel") {
+		if (cpt_ll > i) {
+	                arg_vals->left_label = g_strdup (value);
+			cpt_ll=i;
+		}
+		break;
+        } else if TEST_FOR_I18N_KEY("RightLabel") {
+		if (cpt_rl > i) {
+        	        arg_vals->right_label = g_strdup (value);
+			cpt_rl=i;
+		}
+		break;
+	}
+
+	i++;
+
+    } while (lang);
+
 }
 static
 void set_entry (setup_data *ssd)
@@ -228,6 +325,29 @@ void set_check (setup_data *ssd)
    
         gnome_config_set_bool (ssd->name,(GTK_TOGGLE_BUTTON (ssd->widget)->active));
 }
+static
+void set_color (setup_data *ssd)
+{
+        gchar buffer[60];
+        gushort red, green, blue;
+
+        if (ssd->arg)
+                g_free (ssd->arg);
+        /* Get the colors and convert them to a string. */
+        gnome_color_picker_get_i16 (GNOME_COLOR_PICKER (ssd->widget),
+                                    &red,
+                                    &green,
+                                    &blue,
+                                    NULL); 
+        snprintf (buffer, sizeof(buffer), "#%02x%02x%02x",
+                  red >> 8,
+                  green >> 8,
+                  blue >> 8);
+        gnome_config_set_string (ssd->name, buffer);
+
+        ssd->arg = g_strconcat (ssd->flag1, " ", buffer, NULL);
+}
+
 static GtkAdjustment *
 get_adjustment (gchar *type)
 {
@@ -257,7 +377,7 @@ get_adjustment (gchar *type)
                                 val = low;
                         
                         g_strfreev (temp3);
-                        g_free (temp);
+                        free (temp);
                         /* we add a little to the high value, b/c otherwise the adjustment
                          * won't display the higher value
                          */
@@ -410,6 +530,56 @@ get_check (setup_data *ssd)
         } else
                 return box;
 }
+/* This should prolly honor left_label, but I want to keep the color
+ * buttons aligned vertically. Maybe pack them into a global
+ * gtk_table? Icky. - alh */
+static GtkWidget *
+get_color (setup_data *ssd) {
+        GtkWidget *frame = NULL;
+        GtkWidget *color_button;
+        GtkWidget *alignment;
+        GtkWidget *label;
+        GtkWidget *align;
+        GdkColor selected_color;
+        gchar *prefix;
+        gchar **temp_ptr;
+        gchar *color_string;
+
+        if (ssd->label) 
+                frame = gtk_frame_new (ssd->label);
+
+        /* This will center the color picker in the frame. */
+        alignment = gtk_alignment_new (0.5, 1.0, 0.25, 1.0);
+
+        /* make the color picker with its default (if any) */
+        color_button = gnome_color_picker_new();
+        ssd->widget = color_button;
+        /* ssd->val_type is currently "Color=<#color>", seperate out
+         * <#color> */
+        temp_ptr = g_strsplit(ssd->val_type, "=", -1);
+        prefix = g_strconcat (ssd->name, "=", temp_ptr[1], NULL);
+        color_string = gnome_config_get_string_with_default (prefix, NULL);
+
+        g_free (prefix);
+
+        gdk_color_parse(color_string, &selected_color);
+        gnome_color_picker_set_i16(GNOME_COLOR_PICKER( color_button ),
+                                   selected_color.red,
+                                   selected_color.green,
+                                   selected_color.blue,
+                                   0);
+        gtk_signal_connect (GTK_OBJECT (color_button), "color_set", (GtkSignalFunc) color_callback, ssd);
+        gtk_container_add (GTK_CONTAINER (alignment), color_button);
+
+        /* set the arg to be the current color value */
+        ssd->arg = g_strconcat (ssd->flag1, " ", color_string, NULL);
+        
+        if (frame) {
+                gtk_container_add (GTK_CONTAINER (frame), alignment);
+                return frame;
+        } else
+                return alignment;
+}
 static void
 write_field (setup_data *ssd)
 {
@@ -424,6 +594,9 @@ write_field (setup_data *ssd)
         case CHECK:
                 set_check (ssd);
                 break;
+        case COLOR:
+                set_color (ssd);
+                break;
         default:
         }
 }
@@ -435,7 +608,6 @@ entry_callback (GtkEditable *editable, const gchar *text, gint length, gint *pos
         
         ssd->arg = g_strconcat (ssd->flag1, " \"", gtk_entry_get_text (GTK_ENTRY (editable)),"\"", NULL);
         capplet_widget_state_changed(CAPPLET_WIDGET (capplet), TRUE);
-
 }
 static void
 entry_delete_callback (GtkEditable *editable, gint length, gint *position, setup_data *ssd)
@@ -474,6 +646,24 @@ range_callback (GtkAdjustment *adj, setup_data *ssd)
         ssd->arg = g_strconcat (ssd->flag1, val, NULL);
         capplet_widget_state_changed(CAPPLET_WIDGET (capplet), TRUE);
 }
+static void
+color_callback (GnomeColorPicker *color_button, guint red, guint blue,
+                guint green, guint alpha, setup_data *ssd)
+{
+        gchar buffer[60];
+
+        if (ssd->arg)
+                g_free (ssd->arg);
+
+        /* Get the colors and convert them to a string. */
+        snprintf (buffer, sizeof(buffer), "#%02x%02x%02x",
+                  red >> 8,
+                  green >> 8,
+                  blue >> 8);
+
+        ssd->arg = g_strconcat (ssd->flag1, " ", buffer, NULL);
+        capplet_widget_state_changed(CAPPLET_WIDGET (capplet), TRUE);
+}
 
 /* public functions */
 void
@@ -490,6 +680,10 @@ init_screensaver_data (screensaver_data *sd)
         void *sec_iter;
         void *val_iter;
         setup_data *arg_vals;
+	/* I needed some flag to tell parse_key wheter there is a new
+	 * section or not; so it can reinitialize its own counters -- srtxg
+	 */
+	int cpt_iter;
 
         /* We set up the prefix for most of our gnome_config stuff. */
         prefix = g_strconcat ("=", sd->desktop_filename, "=", NULL);
@@ -497,21 +691,25 @@ init_screensaver_data (screensaver_data *sd)
         /* We determine the current args */
         tempstring = gnome_config_get_string_with_default ("Screensaver Data/DefaultFlags", NULL);
         gnome_config_pop_prefix ();
-        tempstring2 = g_strconcat ("/Screensaver/", sd->name, "/args=", tempstring ,NULL);
+        tempstring2 = g_strconcat ("/Screensaver/", sd->name, "/args=", sd->tryexec, " ", tempstring ,NULL);
         g_free (tempstring);
         sd->args = gnome_config_get_string_with_default (tempstring2, NULL);
         g_free (tempstring2);
 
         /* We determine the setup layout. */
+        gnome_config_drop_file (sd->desktop_filename);
+        gnome_config_drop_file (prefix);
         sec_iter = gnome_config_init_iterator_sections (prefix);
         sd->setup_data = NULL;
         while ((sec_iter = gnome_config_iterator_next (sec_iter, &sec, NULL))) {
                 if (strncmp ("Arg", sec, 3) == 0) {
+			cpt_iter=0; /* there is a new section */
                         arg_vals = new_arg_vals();
                         tempstring = g_strconcat (prefix, "/", sec, "/", NULL);
                         val_iter = gnome_config_init_iterator (tempstring);
                         while ((val_iter = gnome_config_iterator_next (val_iter, &key, &value))) {
-                                parse_key (arg_vals, key, value);
+                                parse_key (arg_vals, key, value, cpt_iter);
+				cpt_iter++;
                                 g_free (key);
                                 g_free (value);
                         }
@@ -557,6 +755,9 @@ get_screensaver_widget (screensaver_data *sd)
                 case CHECK:
                         gtk_box_pack_start (GTK_BOX (vbox), get_check (ssd), FALSE, FALSE, 0);
                         break;
+                case COLOR:
+                        gtk_box_pack_start (GTK_BOX (vbox), get_color (ssd), FALSE, FALSE, 0);
+                        break;
                 default:
                         g_warning ("unknown type trying to be realized");
                 }
