@@ -72,7 +72,7 @@ static GtkWidget *
 get_settings_frame()
 {
         GtkWidget *retval;
-        GtkWidget *frame, *vbox, *dpmscheck, *hbox, *label, *tempvbox;
+        GtkWidget *vbox, *dpmscheck, *hbox, *label, *tempvbox;
         GtkWidget *temphbox, *alignment, *ssentry, *pword, *adjustment;
         GtkWidget *evbox;
         GtkWidget *nice;
@@ -114,7 +114,7 @@ get_settings_frame()
         gtk_box_pack_start (GTK_BOX (temphbox), gtk_label_new (_("Priority:")), FALSE, FALSE, 0);
         gtk_box_pack_start (GTK_BOX (tempvbox), temphbox, FALSE, FALSE, 0);
         temphbox = gtk_hbox_new (FALSE, 0);
-	adjustment = GTK_OBJECT(get_and_set_nice ());
+	adjustment = GTK_WIDGET(get_and_set_nice ());
 					 
 	nice = gtk_hscale_new (GTK_ADJUSTMENT (adjustment));
         gtk_scale_set_draw_value (GTK_SCALE (nice), FALSE);
@@ -234,28 +234,27 @@ main (int argc, char **argv)
 
         if(token) {
                 gchar *command, *r_command;
-                gchar dpmstime[11];
+                gchar dpmscmd[32];
                 gint mypid;
-                command = gnome_config_get_string ("/Screensaver/Default/command=xscreensaver -no-splash -timeout 20 -nice 10 -lock-mode");
-                r_command = g_strconcat (command, " &", NULL);
-                system ("xscreensaver-command -exit");
-
-                system (r_command);
-                g_free (command);
-                g_free (r_command);
-                
-                /* and now, a shameful reuse of variables to handle dpm. (: */
-                mypid = 0;
-                mypid = gnome_config_get_bool ("/Screensaver/Default/dpms=false");
-                if (mypid) {
-                        mypid = gnome_config_get_string ("/Screensaver/Default/dpmsmins=20");
-                        mypid += gnome_config_get_string ("/Screensaver/Default/waitmins=20");
-                        g_snprintf (dpmstime, 10, "%d",(gint) mypid * 60);
-                        r_command = g_strconcat ("xset dpms ", dpmsmins, " ", dpmsmins, " ", dpmsmins, NULL);
+                command = gnome_config_get_string ("/Screensaver/Default/command=xscreensaver -no-splash -timeout 20 -nice 10");
+                if (strcmp (command, "NONE")) {
+                        r_command = g_strconcat (command, " &", NULL);
+                        system ("xscreensaver-command -exit");
                         system (r_command);
                         g_free (r_command);
                 }
+                g_free (command);
+                
+                /* and now, a shameful reuse of variables to handle DPMS. (: */
+                mypid = gnome_config_get_bool ("/Screensaver/Default/dpms=false");
+                if (mypid) {
+                        mypid = gnome_config_get_int ("/Screensaver/Default/dpmsmins=20");
+                        mypid += gnome_config_get_int ("/Screensaver/Default/waitmins=20");
+                        g_snprintf (dpmscmd, sizeof(dpmscmd), "xset dpms 0 0 %d", (gint) mypid * 60);
+                        gnome_execute_shell(".", dpmscmd);
+                }
         }
+
 	if (init_results == 0) {
                 screensaver_load ();
                 screensaver_setup();
