@@ -91,8 +91,8 @@ main(int argc, char *argv[])
                                       argc, argv, NULL, 0, NULL);
 
     if (init_results < 0)
-        g_error ("an initialization error occurred while "
-                 "starting 'sound-properties-capplet'.");
+        g_error (_("an initialization error occurred while "
+                 "starting 'sound-properties-capplet'."));
 
     client = gnome_master_client ();
 
@@ -125,13 +125,6 @@ main(int argc, char *argv[])
     } else
 		token = 1;
 
-#if 0
-    {
-        volatile int x=1;
-        while(x);
-    }
-#endif
-
     switch(init_results) {
     case 1:
 #ifdef HAVE_ESD
@@ -192,7 +185,6 @@ sound_properties_create(void)
         N_("Event"),
         N_("File to Play")
     };
-    gboolean btmp;
     SoundProps *retval;
 
     /* dont tell control center about changes */
@@ -252,7 +244,7 @@ sound_properties_create(void)
     gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, FALSE, 0);
 
     retval->enable_esd_startup =
-        gtk_check_button_new_with_label(_("GNOME sound support"));
+        gtk_check_button_new_with_label(_("Enable sound server startup"));
     gtk_box_pack_start (GTK_BOX (wtmp), retval->enable_esd_startup,
                         FALSE, FALSE, 0);
                         
@@ -376,9 +368,7 @@ static void
 sound_properties_regenerate_ctree(SoundProps *props)
 {
     GString *tmpstr = g_string_new(NULL);
-    GtkWidget *entry;
-    char *ctmp, *ctmp2;
-    GtkWidget *node;
+    char *ctmp;
 
     gtk_clist_freeze(GTK_CLIST(props->ctree));
     gtk_clist_clear(GTK_CLIST(props->ctree));
@@ -420,8 +410,8 @@ sound_properties_read_path(SoundProps *props,
 {
     DIR *dirh;
     SoundEvent *new_entry;
-    char *category_name, *sample_name, *sample_file, *ctmp;
-    gpointer top_iter, event_iter;
+    char *sample_name, *sample_file, *ctmp;
+    gpointer event_iter;
     GtkCTreeNode *category_node = NULL, *event_node = NULL,
         *prev_event_node = NULL;
     char *arow[4] = {NULL,NULL,NULL,NULL};
@@ -502,10 +492,6 @@ sound_properties_read_path(SoundProps *props,
 
                 new_entry = gtk_ctree_node_get_row_data(GTK_CTREE(props->ctree),
                                                         event_node);
-#if 0
-                g_print("Getting entry %p node %p: %s\n", new_entry,
-                        event_node, sample_name);
-#endif
 
                 g_free(new_entry->file);
 
@@ -543,11 +529,6 @@ sound_properties_read_path(SoundProps *props,
                                                  (GtkDestroyNotify)sound_properties_event_free);
                 g_hash_table_insert(cathash, new_entry->name, event_node);
 
-#if 0
-                g_print("Adding entry %p node %p: %s\n", new_entry,
-                        event_node, sample_name);
-#endif
-
                 prev_event_node = event_node;
             }
             gtk_ctree_expand(GTK_CTREE(props->ctree), GTK_CTREE_NODE(category_node));
@@ -559,16 +540,6 @@ sound_properties_read_path(SoundProps *props,
     closedir(dirh);
 }
 
-static void
-sound_properties_event_play(GtkWidget *widget, SoundProps *props)
-{
-    GtkWidget *entry;
-
-    entry = gnome_file_entry_gtk_entry(GNOME_FILE_ENTRY(props->btn_filename));
-
-    gnome_sound_play(gtk_entry_get_text(GTK_ENTRY(entry)));
-}
-
 static void
 sound_properties_event_change_file(GtkEditable *entry, SoundProps *props)
 {
@@ -619,7 +590,6 @@ sound_properties_event_apply(GtkCTree *ctree,
 {
     SoundEvent *ev;
     char *cur_filename = NULL, *ctmp;
-    GtkWidget *entry;
 
     ev = gtk_ctree_node_get_row_data(GTK_CTREE(ctree), node);
 #if 0
@@ -640,18 +610,23 @@ sound_properties_event_apply(GtkCTree *ctree,
     ctmp = g_strconcat("/sound/events/", ev->category, "/", ev->name, "/file", NULL);
     gnome_config_set_string(ctmp, cur_filename);
     g_free(ctmp);
+
+    reload_all_esd_samples();
 }
 
 static void
 sound_properties_apply(SoundProps *props)
 {
+    gboolean esd_startup, sound_events;
     gtk_ctree_post_recursive(GTK_CTREE(props->ctree), NULL,
                              (GtkCTreeFunc)sound_properties_event_apply, props);
 
+    esd_startup = GTK_TOGGLE_BUTTON(props->enable_esd_startup)->active;
+    sound_events = GTK_TOGGLE_BUTTON(props->enable_sound_events)->active;
     gnome_config_set_bool("/sound/system/settings/start_esd",
-                          GTK_TOGGLE_BUTTON(props->enable_esd_startup)->active);
+                          esd_startup);
     gnome_config_set_bool("/sound/system/settings/event_sounds",
-                          GTK_TOGGLE_BUTTON(props->enable_sound_events)->active);
+                          esd_startup && sound_events);
     gnome_config_sync();
     reload_all_esd_samples();
 }
@@ -776,7 +751,7 @@ reload_esd_samples(const char *config_path)
 {
     DIR *dirh;
     char *category_name, *sample_name, *sample_file, *ctmp;
-    gpointer top_iter, event_iter;
+    gpointer event_iter;
     struct dirent *dent;
     GString *tmpstr;
 
