@@ -164,7 +164,7 @@ install_theme_callback (GtkWidget *widget, gpointer data)
 
 }
 
-gint
+static gint
 delete_capplet (GtkWidget *widget, GdkEvent *event, gpointer data)
 {
   /* We don't want the toplevel window destroyed until
@@ -179,7 +179,7 @@ make_main(void)
 {
   void *sw, *label;
   GtkWidget *box, *hbox, *hbox2, *vbox;
-  GtkWidget *text, *frame, *frame2, *button;
+  GtkWidget *frame, *button;
   GtkWidget *button_vbox;
   gboolean default_used;
   
@@ -237,10 +237,26 @@ make_main(void)
   gnome_font_picker_set_mode (GNOME_FONT_PICKER (font_sel),
 			      GNOME_FONT_PICKER_MODE_FONT_INFO);
   initial_font = gnome_config_get_string_with_default ("/theme-switcher-capplet/settings/font",&default_used);
+
+
   if (initial_font == NULL) {
-	  gnome_font_picker_set_font_name (GNOME_FONT_PICKER (font_sel),
-					   initial_font);
+
+    GtkStyle *style;
+    
+    gtk_widget_ensure_style (frame);
+    style = gtk_widget_get_style (frame);
+
+    if (style->rc_style == NULL) {
+      /* FIXME - should really get this from X somehow   */
+      /*         for now we just assume default gtk font */
+      initial_font = g_strdup(_("-adobe-helvetica-medium-r-normal--*-120-*-*-*-*-*-*"));
+    } else {
+      initial_font = style->rc_style->font_name;
+    }
   }
+
+  gnome_font_picker_set_font_name (GNOME_FONT_PICKER (font_sel), initial_font);
+
   gnome_font_picker_fi_set_use_font_in_label (GNOME_FONT_PICKER (font_sel),
 					      TRUE,
 					      12);
@@ -346,7 +362,7 @@ static void
 click_try(GtkWidget *widget, gpointer data)
 {
   gchar *rc;
-  gchar *dir, cmd[10240];
+  gchar *dir;
 
 /*  if (current_theme == current_global_theme)
     return;*/
@@ -393,7 +409,7 @@ static void
 click_revert(GtkWidget *widget, gpointer data)
 {
   gchar *rc;
-  gchar *dir, cmd[10240];
+  gchar *dir;
 
   widget = initial_theme;
   if (!widget)
@@ -425,10 +441,12 @@ click_revert(GtkWidget *widget, gpointer data)
   ignore_change = TRUE;
   gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (auto_preview),
 			       initial_preview);
+  
   gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (font_cbox),
 			       initial_font_cbox);
-  gnome_font_picker_set_font_name (GNOME_FONT_PICKER (font_sel),
-				   initial_font);
+  if (initial_font)
+    gnome_font_picker_set_font_name (GNOME_FONT_PICKER (font_sel),
+				     initial_font);
   gtk_list_select_child (GTK_LIST (theme_list), initial_theme);
   test_theme(rc, initial_font);
   send_reread();
@@ -442,9 +460,7 @@ click_revert(GtkWidget *widget, gpointer data)
 static void
 click_entry(GtkWidget *widget, gpointer data)
 {
-  gchar *rc, *name, *new_readme, buf[1024];
-  FILE *f;
-  
+  gchar *rc, *name;
   
   name = (gchar *)gtk_object_get_data(GTK_OBJECT(widget), "name");
   rc = (gchar *)gtk_object_get_data(GTK_OBJECT(widget), "rc");
