@@ -31,10 +31,11 @@ typedef struct {
 /* vars. */
 static GtkWidget *capplet;
 static GtkWidget *delete_button;
+static GtkWidget *edit_button;
 static GtkWidget *config_button;
 static GtkWidget *clist;
 
-static WindowManager *selected_wm;
+static WindowManager *selected_wm = NULL;
 
 static GtkWidget *restart_dialog = NULL;
 static GtkWidget *restart_label = NULL;
@@ -117,6 +118,17 @@ gboolean restart_pending = FALSE;
  */
 gboolean in_fill = FALSE;
 
+static GtkWidget *
+left_aligned_button (gchar *label)
+{
+  GtkWidget *button = gtk_button_new_with_label (label);
+  gtk_misc_set_alignment (GTK_MISC (GTK_BIN (button)->child),
+			  0.0, 0.5);
+  gtk_misc_set_padding (GTK_MISC (GTK_BIN (button)->child),
+			GNOME_PAD_SMALL, 0);
+
+  return button;
+}
 static void
 restart_label_update (void)
 {
@@ -125,8 +137,8 @@ restart_label_update (void)
         if ((gint)restart_remaining_time != restart_displayed_time) {
                 restart_displayed_time = restart_remaining_time;
                 
-                tmp = g_strdup_printf ("Starting %s\n"
-                                       "(%d seconds left before operation times out)",
+                tmp = g_strdup_printf (_("Starting %s\n"
+                                         "(%d seconds left before operation times out)"),
                                        restart_name,
                                        restart_displayed_time);
                 gtk_label_set_text (GTK_LABEL (restart_label), tmp);
@@ -273,7 +285,7 @@ update_gui (void)
         WindowManager *current_wm = wm_list_get_current();
         gint new_row;
         gchar *tmpstr;
-        
+
         gtk_clist_clear (GTK_CLIST (clist));
 
         in_fill = TRUE;
@@ -286,11 +298,11 @@ update_gui (void)
                 wm = tmp_list->data;
 
                 if (wm == current_wm) {
-                        row_text = g_strconcat (wm->dentry->name, " (Current)", NULL);
+                        row_text = g_strdup_printf (_("%s (Current)"),
+                                              wm->dentry->name);
 
-                        tmpstr = g_strconcat ("Run Configuration Tool for ",
-                                              wm->dentry->name,
-                                              NULL);
+                        tmpstr = g_strdup_printf (_("Run Configuration Tool for %s"),
+                                              wm->dentry->name);
                                               
                         gtk_label_set_text (GTK_LABEL (GTK_BIN (config_button)->child),
                                             tmpstr);
@@ -299,7 +311,8 @@ update_gui (void)
 
                         g_free (tmpstr);
                 } else if (wm->is_user && !wm->is_present) {
-                        row_text = g_strconcat (wm->dentry->name, " (Not found)", NULL);
+                        row_text = g_strconcat (wm->dentry->name,
+                                                _(" (Not found)"), NULL);
                 } else {
                         row_text = g_strdup (wm->dentry->name);
                 }
@@ -317,7 +330,18 @@ update_gui (void)
         
         in_fill = FALSE;
 
-        gtk_widget_set_sensitive (delete_button, selected_wm->is_user);
+        if(selected_wm) {
+                gtk_widget_set_sensitive (edit_button, selected_wm->is_user);
+                gtk_widget_set_sensitive (delete_button, selected_wm->is_user);
+        } else {
+                gtk_widget_set_sensitive (edit_button, FALSE);
+                gtk_widget_set_sensitive (delete_button, FALSE);
+        }
+
+        if (current_wm)
+                gtk_widget_show(config_button);
+        else
+                gtk_widget_hide(config_button);
 }
 
 static void 
@@ -327,12 +351,12 @@ init_callback (WMResult result, gpointer data)
         case WM_SUCCESS:
                 break;
         case WM_ALREADY_RUNNING:
-                g_warning ("wm-properties-capplet: Unable to initialize window manager.\n"
-                           "\tAnother window manager is already running and could not be killed\n");
+                g_warning (_("wm-properties-capplet: Unable to initialize window manager.\n"
+                           "\tAnother window manager is already running and could not be killed\n"));
                 break;
         case WM_CANT_START:
-                g_warning ("wm-properties-capplet: Unable to initialize window manager.\n"
-                           "\t'%s' didn't start\n", (gchar *)data);
+                g_warning (_("wm-properties-capplet: Unable to initialize window manager.\n"
+                           "\t'%s' didn't start\n"), (gchar *)data);
                 break;
         }
 
@@ -380,7 +404,7 @@ restart_failure (WMResult reason)
         /* Did the previous window manager not die?
          */
         if (reason == WM_ALREADY_RUNNING) {
-                msg = g_strdup ("Previous window manager did not die\n");
+                msg = g_strdup (_("Previous window manager did not die\n"));
 
                 switch (state) {
                 case STATE_TRY:
@@ -413,10 +437,10 @@ restart_failure (WMResult reason)
                 case STATE_REVERT:
                 case STATE_OK:
                 case STATE_CANCEL:
-                        msg = g_strdup_printf ("Could not start '%s'.\n"
-                                               "Falling back to previous window manager '%s'\n",
-                                               selected_wm->dentry->name,
-                                               current_wm->dentry->name);
+                        msg = g_strdup_printf (_("Could not start '%s'.\n"
+                                                 "Falling back to previous window manager '%s'\n"),
+                                               selected_wm?selected_wm->dentry->name:"Unknown",
+                                               current_wm?current_wm->dentry->name:"Unknown");
                         selected_wm = current_wm;
                         restart(TRUE);
                         break;
@@ -444,11 +468,10 @@ restart_failure (WMResult reason)
                         /* Fall through */
                 case STATE_TRY:
                 case STATE_REVERT:
-                        msg = g_strdup (
-                                        "Could not start fallback window manager.\n"
-                                        "Please run a window manager manually. You can\n"
-                                        "do this by selecting \"Run Program\" in the\n"
-                                        "foot menu\n");
+                        msg = g_strdup (_("Could not start fallback window manager.\n"
+                                          "Please run a window manager manually. You can\n"
+                                          "do this by selecting \"Run Program\" in the\n"
+                                          "foot menu\n"));
                         
                         restart_finalize();
                         break;
@@ -521,14 +544,32 @@ destroy_callback (GtkWidget *widget, void *data)
 static void
 restart (gboolean force)
 {
-        WindowManager *current_wm = wm_list_get_current();
+        WindowManager *current_wm = wm_list_get_current(), *mywm;
+        static gboolean last_try_was_twm = FALSE;
+        const char *twm_argv[] = {"twm", NULL};
+        const GnomeDesktopEntry twm_dentry = {"twm", "twm",
+                                              1, (char **)twm_argv, NULL,
+                                              NULL, NULL, 0, NULL,
+                                              NULL, NULL, 0, 0};
+        const WindowManager twm_fallback = {(GnomeDesktopEntry*)&twm_dentry, "twm", "twm", 0, 0, 1, 0};
 
-        if (force || current_wm != selected_wm) {
-                show_restart_dialog (selected_wm->dentry->name);
+        if(selected_wm) {
+                last_try_was_twm = FALSE;
+                mywm = selected_wm;
+        } else if(!last_try_was_twm) {
+                last_try_was_twm = TRUE;
+                mywm = (WindowManager*)&twm_fallback;
+        } else {
+                restart_finalize();
+                return;
+        }
+
+        if (force || current_wm != mywm) {
+                show_restart_dialog (mywm->dentry->name);
                 if (state != STATE_OK && state != STATE_CANCEL)
                         gtk_widget_set_sensitive (capplet, FALSE);
                 restart_pending = TRUE;
-                wm_restart (selected_wm, 
+                wm_restart (mywm, 
                             capplet->window, 
                             restart_callback, 
                             NULL);
@@ -588,16 +629,6 @@ ok_callback (void)
         }
 }
 
-static void
-do_revert (void)
-{
-        wm_list_revert();
-        selected_wm = wm_list_get_revert();
-        if (state != STATE_CANCEL)
-                update_gui();
-        restart(FALSE);
-}
-
 static void
 revert_callback (void)
 {
@@ -669,8 +700,8 @@ create_dialog (gchar *title)
 
         dialog = g_new (WMDialog, 1);
         
-        dialog->dialog = gnome_dialog_new ("Add New Window Manager",
-                                           "OK", "Cancel", NULL);
+        dialog->dialog = gnome_dialog_new (_("Add New Window Manager"),
+                                           _("OK"), _("Cancel"), NULL);
 
         gnome_dialog_set_default (GNOME_DIALOG (dialog->dialog), 0);
         gnome_dialog_close_hides (GNOME_DIALOG (dialog->dialog), TRUE);
@@ -681,7 +712,7 @@ create_dialog (gchar *title)
         gtk_container_add (GTK_CONTAINER (GNOME_DIALOG (dialog->dialog)->vbox),
                            table);
         
-        label = gtk_label_new ("Name:");
+        label = gtk_label_new (_("Name:"));
         gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
         gtk_table_attach (GTK_TABLE (table), label,
                           0, 1, 0, 1,
@@ -694,7 +725,7 @@ create_dialog (gchar *title)
                           GTK_FILL | GTK_EXPAND, 0,
                           0, 0);
 
-        label = gtk_label_new ("Command:");
+        label = gtk_label_new (_("Command:"));
         gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
         gtk_table_attach (GTK_TABLE (table), label,
                           0, 1, 1, 2,
@@ -707,7 +738,7 @@ create_dialog (gchar *title)
                           GTK_FILL | GTK_EXPAND, 0,
                           0, 0);
 
-        label = gtk_label_new ("Configuration Command:");
+        label = gtk_label_new (_("Configuration Command:"));
         gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
         gtk_table_attach (GTK_TABLE (table), label,
                           0, 1, 2, 3,
@@ -726,7 +757,7 @@ create_dialog (gchar *title)
                           GTK_FILL | GTK_EXPAND, 0,
                           0, 0);
         
-        dialog->sm_toggle = gtk_check_button_new_with_label ("Window manager is session managed");
+        dialog->sm_toggle = gtk_check_button_new_with_label (_("Window manager is session managed"));
         gtk_container_add (GTK_CONTAINER (alignment), dialog->sm_toggle);
 
         gtk_window_set_default_size (GTK_WINDOW (dialog->dialog), 400, -1);
@@ -776,16 +807,16 @@ check_dialog (WMDialog *dialog)
         GtkWidget *msgbox;
         
         if (is_blank (gtk_entry_get_text (GTK_ENTRY (dialog->name_entry)))) {
-                msgbox = gnome_message_box_new ("Name cannot be empty",
+                msgbox = gnome_message_box_new (_("Name cannot be empty"),
                                                 GNOME_MESSAGE_BOX_ERROR,
-                                                "OK", NULL);
+                                                _("OK"), NULL);
                 gnome_dialog_run (GNOME_DIALOG (msgbox));
                 return FALSE;
         }
         if (is_blank (gtk_entry_get_text (GTK_ENTRY (dialog->exec_entry)))) {
-                msgbox = gnome_message_box_new ("Command cannot be empty",
+                msgbox = gnome_message_box_new (_("Command cannot be empty"),
                                                 GNOME_MESSAGE_BOX_ERROR,
-                                                "OK", NULL);
+                                                _("OK"), NULL);
                 gnome_dialog_run (GNOME_DIALOG (msgbox));
                 return FALSE;
         }
@@ -825,10 +856,15 @@ get_dialog_contents (WMDialog *dialog, WindowManager *wm)
 static void
 edit_dialog (void)
 {
-        WMDialog *dialog = create_dialog ("Add New Window Manager");
+        WMDialog *dialog;
         gchar *tmp;
         gint result;
 
+        if(!selected_wm)
+                return;
+
+        dialog = create_dialog (_("Edit Window Manager"));
+
         if (selected_wm->dentry->name)
                 gtk_entry_set_text (GTK_ENTRY (dialog->name_entry), selected_wm->dentry->name);
                 
@@ -869,7 +905,7 @@ edit_dialog (void)
 static void
 add_dialog (void)
 {
-        WMDialog *dialog = create_dialog ("Edit Window Manager");
+        WMDialog *dialog = create_dialog (_("Edit Window Manager"));
         WindowManager *wm;
         gint result;
 
@@ -924,8 +960,8 @@ delete (void)
         
         if (current_wm == selected_wm) {
                 msgbox = gnome_message_box_new (
-                   "You cannot delete the current Window Manager",
-                   GNOME_MESSAGE_BOX_ERROR, "OK", NULL);
+                   _("You cannot delete the current Window Manager"),
+                   GNOME_MESSAGE_BOX_ERROR, _("OK"), NULL);
 
                 gnome_dialog_run (GNOME_DIALOG (msgbox));
                 return;
@@ -939,11 +975,13 @@ delete (void)
 
 
 static void
-run_config (void)
+run_config (GtkWidget *w)
 {
         WindowManager *current_wm = wm_list_get_current();
-        if (current_wm->is_config_present &&
-            current_wm->config_exec != NULL) {
+
+        if (current_wm
+            && current_wm->is_config_present
+            && current_wm->config_exec != NULL) {
                 gchar *argv[4];
 
                 argv[0] = "/bin/sh";
@@ -961,7 +999,6 @@ wm_setup (void)
         GtkWidget *hbox, *vbox, *bottom;
         GtkWidget *util_vbox;
         GtkWidget *add_button;
-        GtkWidget *edit_button;
         GtkWidget *scrolled_window;
 
         capplet = capplet_widget_new ();
@@ -991,17 +1028,17 @@ wm_setup (void)
         util_vbox = gtk_vbox_new (FALSE, GNOME_PAD_SMALL);
         gtk_box_pack_start (GTK_BOX (hbox), util_vbox, FALSE, FALSE, 0);
         
-        add_button = gtk_button_new_with_label ("Add");
+        add_button = left_aligned_button (_("Add..."));
         gtk_signal_connect (GTK_OBJECT (add_button), "clicked",
                             GTK_SIGNAL_FUNC (add_dialog), NULL);
         gtk_box_pack_start (GTK_BOX (util_vbox), add_button, FALSE, FALSE, 0);
 
-        edit_button = gtk_button_new_with_label ("Edit");
+        edit_button = left_aligned_button (_("Edit..."));
         gtk_signal_connect (GTK_OBJECT (edit_button), "clicked",
                             GTK_SIGNAL_FUNC (edit_dialog), NULL);
         gtk_box_pack_start (GTK_BOX (util_vbox), edit_button, FALSE, FALSE, 0);
 
-        delete_button = gtk_button_new_with_label ("Delete");
+        delete_button = left_aligned_button (_("Delete"));
         gtk_signal_connect (GTK_OBJECT (delete_button), "clicked",
                             GTK_SIGNAL_FUNC (delete), NULL);
         gtk_box_pack_start (GTK_BOX (util_vbox), delete_button, FALSE, FALSE, 0);
@@ -1018,9 +1055,9 @@ wm_setup (void)
 
         gtk_container_add (GTK_CONTAINER (capplet), vbox);
 
-        update_gui();
-
         gtk_widget_show_all (capplet);
+
+        update_gui();
 }
 
 int
@@ -1036,9 +1073,9 @@ main (int argc, char **argv)
 					  argc, argv, NULL, 0, NULL);
         
 	if (init_results < 0) {
-                g_warning ("an initialization error occurred while "
-			   "starting 'wm-properties-capplet'.\n"
-                           "aborting...\n");
+                g_warning (_("an initialization error occurred while "
+                             "starting 'wm-properties-capplet'.\n"
+                             "aborting...\n"));
                 exit (1);
 	}
 
