@@ -43,6 +43,7 @@ exit_callback(GtkWidget *widget, gpointer data)
 void
 exit_dialog_ok_callback(GtkWidget *widget, gpointer data)
 {
+        revert_all ();
         gtk_widget_destroy (main_window);
         control_center_corba_gtk_main_quit();
 }
@@ -53,6 +54,11 @@ exit_dialog_cancel_callback(GtkWidget *widget, gpointer data)
         exit_dialog = NULL;
 }
 void
+exit_dialog_close_callback(GtkWidget *widget, gpointer data)
+{
+        exit_dialog = NULL;
+}
+void
 help_callback (GtkWidget *widget, gpointer data)
 {
         gchar *tmp;
