@@ -174,7 +174,7 @@ capplet_corba_gtk_main_quit (void)
 {
         CORBA_Object_release (control_center, &ev);
         CORBA_ORB_shutdown(orb, CORBA_FALSE, &ev);
-        gtk_main_quit();
+        exit (0);
 }
 void
 capplet_corba_state_changed (gint id, gboolean undoable)
