@@ -186,9 +186,7 @@ capplet_widget_multi_new (gint capid)
 void
 capplet_widget_state_changed(CappletWidget *cap, gboolean undoable)
 {
-        g_print ("in capplet_widget_state_changed\n");
         if (cap->changed == FALSE) {
-                g_print ("\tchanging state\n");
                 capplet_corba_state_changed (cap->control_center_id, undoable);
                 cap->changed = TRUE;
         }
@@ -199,6 +197,7 @@ capplet_gtk_main (void)
 {
         capplet_corba_gtk_main();
 }
+
 gint
 gnome_capplet_init (const char *app_id, const char *app_version,
                     int argc, char **argv, struct poptOption *options,
