@@ -317,16 +317,16 @@ generate_tree ()
 }
 
 void
-selected_row_callback (GtkWidget *widget, GtkCTreeNode *node, gint column)
+selected_row_callback (GtkWidget *widget, GtkCTreeNode *node, gint column, gpointer data)
 {
         node_data *data;
         GnomeDesktopEntry *gde;
         GdkEvent *event = gtk_get_current_event();
 
-        if (column < 0)
-                return;
-        
         data = (node_data *) gtk_ctree_node_get_row_data (GTK_CTREE (widget),node);
+        if (data == NULL)
+                return;
+
         gde = (GnomeDesktopEntry *)data->gde; 
         gnome_appbar_pop (GNOME_APPBAR (status_bar));
         if (gde->comment)
