@@ -21,7 +21,7 @@ GtkWidget *generate_tree ();
 gint button_press (GtkCTree *ctree, GdkEventButton *event, gpointer data);
 
 /* callbacks */
-void selected_row_callback (GtkWidget *widget, GtkCTreeNode *node, gint column);
+void selected_row_callback (GtkWidget *widget, GtkCTreeNode *node, gint column, gpointer unseen);
         
 typedef enum
 {
